#!/usr/bin/env ruby
=begin
/****************************************************************
**
** Qt tutorial 2
**
****************************************************************/
=end
require "qte"
include Qte
require "qpe"
include Qpe

    a = QPEApplication.new( [$0]+ARGV)

    quit = QPushButton.new( "Quit", nil )
    quit.resize( 75, 30 );
    quit.setFont( QFont.new( "Times", 18, QFont::Bold ) )

    Qte::connect( quit, QSIGNAL("clicked()"), a, "quit" )

    a.showMainWidget( quit )
    a.exec()
